@@ -469,11 +469,14 @@ RedshiftSettingsTypeDef = TypedDict(
         "AfterConnectScript": str,
         "BucketFolder": str,
         "BucketName": str,
+        "CaseSensitiveNames": bool,
+        "CompUpdate": bool,
         "ConnectionTimeout": int,
         "DatabaseName": str,
         "DateFormat": str,
         "EmptyAsNull": bool,
         "EncryptionMode": Literal["sse-s3", "sse-kms"],
+        "ExplicitIds": bool,
         "FileTransferUploadStreams": int,
         "LoadTimeout": int,
         "MaxFileSize": int,
